window.Gleam.initSearch([{"doc":"reactive_signal","title":"reactive_signal","content":"# reactive_signal\n\nA Gleam library for cross-process reactive signal\n\n&gt; [!WARNING]\n&gt; This is an experimental library, so breaking changes are actively made\n\n[![Package Version](https://img.shields.io/hexpm/v/reactive_signal)](https://hex.pm/packages/reactive_signal)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/reactive_signal/)\n\n```sh\ngleam add reactive_signal\n```\n\n```gleam\nimport reactive_signal\n\npub fn main() {\n  let new_listener = fn(logger) {\n    fn(value) { process.send(logger, &quot;Listened:&quot; &lt;&gt; int.to_string(value)) }\n  }\n\n  let new_app = fn(logger: Subject(String)) {\n    let #(sig, chn) = signal.new(0)\n    let #(sig2, chn2) = signal.new(0)\n    let sig3 = {\n      use x &lt;- signal.chain(sig)\n      use y &lt;- signal.chain(sig2)\n      signal.pure(x + y)\n    }\n    signal.subscribe(sig3, new_listener(logger))\n    channel.write(chn, 1)\n    channel.write(chn2, 1)\n  }\n\n  let logger = process.new_subject()\n  new_app(logger)\n\n  process.receive(logger, 10)\n  |&gt; should.equal(Ok(&quot;Listened:0&quot;))\n\n  process.receive(logger, 10)\n  |&gt; should.equal(Ok(&quot;Listened:1&quot;))\n\n  process.receive(logger, 10)\n  |&gt; should.equal(Ok(&quot;Listened:2&quot;))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/reactive_signal&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"reactive_signal/channel","title":"Channel","content":"pub opaque type Channel(s)\n A variable that can be subscribed\n\nSynonyms:\nreactive_signal/channel.Channel\nreactive_signal/channel Channel","url":"reactive_signal/channel.html#Channel"},{"doc":"reactive_signal/channel","title":"modify","content":"pub fn modify(channel: Channel(a), f: fn(a) -&gt; a) -&gt; a\n Apply function to channel value\nSynonyms:\nreactive_signal/channel.modify\nreactive_signal/channel modify","url":"reactive_signal/channel.html#modify"},{"doc":"reactive_signal/channel","title":"new","content":"pub fn new(initial_value: a) -&gt; Channel(a)\n Create a new channel\nSynonyms:\nreactive_signal/channel.new\nreactive_signal/channel new","url":"reactive_signal/channel.html#new"},{"doc":"reactive_signal/channel","title":"subscribe","content":"pub fn subscribe(\n  channel: Channel(a),\n  new_subscriber: fn(a) -&gt; Nil,\n) -&gt; Nil\n Subscribe to a channel\n Subscriber is start as a new process, and exit when the next value is published, or parent process is exit.\nSynonyms:\nreactive_signal/channel.subscribe\nreactive_signal/channel subscribe","url":"reactive_signal/channel.html#subscribe"},{"doc":"reactive_signal/channel","title":"subscribe_from_subject","content":"pub fn subscribe_from_subject(\n  channel: Channel(a),\n  subscriber_subject: Subject(a),\n) -&gt; Nil\n Subscribe to a channel by Subject.\n Subject will receive messages when the channel value is updated.\nSynonyms:\nreactive_signal/channel.subscribe_from_subject\nreactive_signal/channel subscribe_from_subject","url":"reactive_signal/channel.html#subscribe_from_subject"},{"doc":"reactive_signal/channel","title":"subscribe_with_wait_next","content":"pub fn subscribe_with_wait_next(\n  channel: Channel(a),\n  new_subscriber: fn(a, fn() -&gt; Nil) -&gt; Nil,\n) -&gt; Nil\n Subscribe to a channel\n Subscriber is start as a new process, and exit when the next value is published, or parent process is exit.\nSynonyms:\nreactive_signal/channel.subscribe_with_wait_next\nreactive_signal/channel subscribe_with_wait_next","url":"reactive_signal/channel.html#subscribe_with_wait_next"},{"doc":"reactive_signal/channel","title":"try_modify","content":"pub fn try_modify(\n  channel: Channel(a),\n  f: fn(a) -&gt; a,\n) -&gt; Result(a, CallError(a))\n Apply function to channel value safely\nSynonyms:\nreactive_signal/channel.try_modify\nreactive_signal/channel try_modify","url":"reactive_signal/channel.html#try_modify"},{"doc":"reactive_signal/channel","title":"try_write","content":"pub fn try_write(\n  channel: Channel(a),\n  s: a,\n) -&gt; Result(Nil, CallError(a))\n Write value to channel safely\nSynonyms:\nreactive_signal/channel.try_write\nreactive_signal/channel try_write","url":"reactive_signal/channel.html#try_write"},{"doc":"reactive_signal/channel","title":"write","content":"pub fn write(channel: Channel(a), s: a) -&gt; Nil\n Write value to channel\nSynonyms:\nreactive_signal/channel.write\nreactive_signal/channel write","url":"reactive_signal/channel.html#write"},{"doc":"reactive_signal/channel","title":"reactive_signal/channel","content":"","url":"reactive_signal/channel.html"},{"doc":"reactive_signal/signal","title":"Signal","content":"pub opaque type Signal(s)\n Signal is read-only, but chainable Channel.\n\nSynonyms:\nreactive_signal/signal.Signal\nreactive_signal/signal Signal","url":"reactive_signal/signal.html#Signal"},{"doc":"reactive_signal/signal","title":"chain","content":"pub fn chain(sig: Signal(a), f: fn(a) -&gt; Signal(b)) -&gt; Signal(b)\n\nSynonyms:\nreactive_signal/signal.chain\nreactive_signal/signal chain","url":"reactive_signal/signal.html#chain"},{"doc":"reactive_signal/signal","title":"from_channel","content":"pub fn from_channel(chn: Channel(a)) -&gt; Signal(a)\n\nSynonyms:\nreactive_signal/signal.from_channel\nreactive_signal/signal from_channel","url":"reactive_signal/signal.html#from_channel"},{"doc":"reactive_signal/signal","title":"map","content":"pub fn map(sig: Signal(a), f: fn(a) -&gt; b) -&gt; Signal(b)\n\nSynonyms:\nreactive_signal/signal.map\nreactive_signal/signal map","url":"reactive_signal/signal.html#map"},{"doc":"reactive_signal/signal","title":"new","content":"pub fn new(init: a) -&gt; #(Signal(a), Channel(a))\n\nSynonyms:\nreactive_signal/signal.new\nreactive_signal/signal new","url":"reactive_signal/signal.html#new"},{"doc":"reactive_signal/signal","title":"pure","content":"pub fn pure(a: a) -&gt; Signal(a)\n\nSynonyms:\nreactive_signal/signal.pure\nreactive_signal/signal pure","url":"reactive_signal/signal.html#pure"},{"doc":"reactive_signal/signal","title":"subscribe","content":"pub fn subscribe(\n  signal: Signal(a),\n  new_subscriber: fn(a) -&gt; Nil,\n) -&gt; Nil\n Subscribe to a channel\n Subscriber is start as a new process, and exit when the next value is published, or parent process is exit.\nSynonyms:\nreactive_signal/signal.subscribe\nreactive_signal/signal subscribe","url":"reactive_signal/signal.html#subscribe"},{"doc":"reactive_signal/signal","title":"subscribe_from_subject","content":"pub fn subscribe_from_subject(\n  signal: Signal(a),\n  subscriber_subject: Subject(a),\n) -&gt; Nil\n Subscribe to a channel by Subject.\n Subject will receive messages when the channel value is updated.\nSynonyms:\nreactive_signal/signal.subscribe_from_subject\nreactive_signal/signal subscribe_from_subject","url":"reactive_signal/signal.html#subscribe_from_subject"},{"doc":"reactive_signal/signal","title":"subscribe_with_wait_next","content":"pub fn subscribe_with_wait_next(\n  signal: Signal(a),\n  new_subscriber: fn(a, fn() -&gt; Nil) -&gt; Nil,\n) -&gt; Nil\n Subscribe to a channel with a wait_next function, that will wait for the next value to be published.\nSynonyms:\nreactive_signal/signal.subscribe_with_wait_next\nreactive_signal/signal subscribe_with_wait_next","url":"reactive_signal/signal.html#subscribe_with_wait_next"},{"doc":"reactive_signal/signal","title":"reactive_signal/signal","content":"","url":"reactive_signal/signal.html"}]);